import pandas as pd
from mongoengine.base import BaseField


class PandasField(BaseField):
    def __init__(self, **kwargs):
        super(PandasField, self).__init__(**kwargs)

    def __set__(self, instance, value):
        if value is not None:
            value = self.to_mongo(value)
        super(PandasField, self).__set__(instance, value)

    def __get__(self, instance, owner):
        x = super(PandasField, self).__get__(instance, owner)
        if x is not None:
            x = self.to_python(x)

        return x


class SeriesField(PandasField):
    def to_mongo(self, value):
        assert isinstance(value, pd.Series)
        return value.to_json(orient="split")

    def to_python(self, value):
        return pd.read_json(value, orient="split", typ="series")


class FrameField(PandasField):
    def to_mongo(self, value):
        assert isinstance(value, pd.DataFrame)
        return value.to_json(orient="table")

    def to_python(self, value):
        return pd.read_json(value, orient="table", typ="frame")



#!/usr/bin/env python
from setuptools import setup, find_packages
from antarctic import __version__ as version

# read the contents of your README file
with open('README.md') as f:
    long_description = f.read()

setup(
    name='antarctic',
    long_description=long_description,
    long_description_content_type='text/markdown',
    version=version,
    packages=find_packages(include=["antarctic*"]),
    author='Thomas Schmelzer',
    author_email='thomas.schmelzer@gmail.com',
    url='https://github.com/tschm/antarctic',
    description='Storing Pandas Data in a MongoDB database',
    install_requires=['requests>=2.23.0', 'pandas>=0.25.3', 'pymongo>=3.10.1', 'mongoengine>=0.19.1'],
    license='MIT'
)



import pandas as pd
import pandas.testing as pt
import pytest
from mongoengine import Document, connect

from antarctic.PandasFields import SeriesField, FrameField
from test.config import read_pd

client = connect(db="test", host="mongomock://localhost")


class Singer(Document):
    close = SeriesField()
    prices = FrameField()


def test_series():
    s = Singer()
    ts = pd.Series(index=[1, 2, 3], data=[2, 3, 4])
    s.close = ts
    pt.assert_series_equal(s.close, ts)

    with pytest.raises(AssertionError):
        s.close = 6.0


def test_frame():
    s = Singer()
    frame = read_pd("price.csv", index_col=0)
    s.prices = frame
    pt.assert_frame_equal(s.prices, frame)

    with pytest.raises(AssertionError):
        s.prices = 2.0
